@@ -461,7 +461,7 @@ Object* Analitza::derivative(const QString &var, const Container *c)
 	} else {
 		Container *cret = new Container(c->containerType());
 		Container::const_iterator it = c->m_params.begin(), end=c->m_params.end();
-		for(; it!=end; it++) {
+		for(; it!=end; ++it) {
 			cret->m_params.append(derivative(var, *it));
 		}
 		return cret;
@@ -491,7 +491,8 @@ Object* Analitza::calcPiecewise(const Container* c)
 		} else {
 			//it is an otherwise
 			if(otherwise)
-				m_err << i18n("Too much <em>otherwise</em> parameters");
+				m_err << i18nc("this is an error message. otherwise is the else in a mathml condition",
+					"Too many <em>otherwise</em> parameters");
 			else
 				otherwise=p;
 		}
@@ -500,8 +501,7 @@ Object* Analitza::calcPiecewise(const Container* c)
 		if(otherwise)
 			r=otherwise->m_params[0];
 		else
-			m_err << i18nc("Piecewise is how the contional is called here",
-				       "Piecewise without otherwise nor matching piece.");
+			m_err << i18nc("Error message, no proper condition found.", "Could not find a proper choice for a condition statement.");
 	}
 				
 	if(r)
@@ -626,7 +626,7 @@ Object* Analitza::operate(const Container* c)
 			} else {
 				QList<Object*> numbers;
 				Container::const_iterator it = c->firstValue(), itEnd=c->m_params.constEnd();
-				for(; it!=itEnd; it++) {
+				for(; it!=itEnd; ++it) {
 					numbers.append(calc(*it));
 				}
 				
@@ -651,14 +651,16 @@ Object* Analitza::operate(const Container* c)
 							bool correct;
 							ret=Operations::reduce(opt, ret, *it, correct);
 							if(!correct)
-								m_err.append(i18n("Can't calculate the %1(%2, %3)",
+								m_err.append(i18nc("%1 the operation name, %2 and %3 is the opearation we wanted to calculate",
+											"Cannot calculate the %1(%2, %3)",
 											op.toString(), ret->toString(), (*it)->toString()));
 						}
 					} else {
 						bool correct;
 						ret=Operations::reduceUnary(opt, ret, correct);
 						if(!correct)
-							m_err.append(i18n("Can't calculate the %1 %2", ret->toString(), op.toString()));
+							m_err.append(i18nc("%1 is the opearation we wanted to calculate, %2 the operation name",
+									"Cannot calculate the %1 '%2'", ret->toString(), op.toString()));
 					}
 				} else {
 					ret = numbers.first();
@@ -764,7 +766,7 @@ Object* Analitza::selector(const Object* index, const Object* vector)
 		
 		int select=cIdx->intValue();
 		if(select<1 || (select-1) > cVect->m_params.count()) {
-			m_err << i18n("Unvalid index for a container");
+			m_err << i18n("Invalid index for a container");
 			ret=new Cn(0.);
 		} else {
 			ret=Expression::objectCopy(cVect->m_params[select-1]);
@@ -839,6 +841,7 @@ void Analitza::levelOut(Container *c, Container *ob, Container::iterator &pos)
 	Container::iterator it = ob->firstValue();
 	for(; it!=ob->m_params.end();) {
 		pos=c->m_params.insert(pos, *it);
+		
 		pos++;
 		it=ob->m_params.erase(it);
 	}
@@ -931,9 +934,20 @@ Object* Analitza::simp(Object* root)
 						d=false;
 						if((*it)->isContainer()) {
 							Container *intr = (Container*) *it;
-							if(intr->containerType()==Container::apply && intr->firstOperator()==Operator::plus) {
-								levelOut(c, intr, it);
-								d=true;
+							if(intr->containerType()==Container::apply && intr->firstOperator()==o) {
+								
+// 								qDebug() << "-------- before1" << (*it)->toString();
+// 								objectWalker(c);
+								
+// 								qDebug() << "-------- middle1" << (*it)->toString();
+// 								objectWalker(c);
+								if(!intr->isUnary() || intr->firstOperator().operatorType()!=Operator::minus) {
+									levelOut(c, intr, it);
+									d=true;
+								}
+// 								qDebug() << "-------- after1";
+// 								objectWalker(c);
+// 								qDebug() << "-------- done1";
 							}
 						}
 						
@@ -950,18 +964,31 @@ Object* Analitza::simp(Object* root)
 					}
 					
 					root=c;
+					
 					if(c->isUnary() && c->firstOperator()==Operator::plus) {
 						root=*c->firstValue();
 						*c->firstValue()=0;
 						delete c;
 						c=0;
-					} else if(somed && c->isUnary() && c->firstOperator()==Operator::minus) {
-						if(!lastdel) {
-							Container *aux=c;
+					} else if(c->isUnary() && c->firstOperator()==Operator::minus) {
+						if(somed && !lastdel) {
 							root=*c->firstValue();
-							*aux->firstValue()=0;
-							delete aux;
+							*c->firstValue()=0;
+							delete c;
 							c=0;
+						} else if((*c->firstValue())->isContainer()) {
+							Container *c1=(Container*) *c->firstValue();
+							if(c1->containerType()==Container::apply &&
+								c1->firstOperator().operatorType()==Operator::minus &&
+								c1->isUnary())
+							{
+								root=*c1->firstValue();
+								*c->firstValue()=0;
+								*c1->firstValue()=0;
+								delete c;
+								delete c1;
+								c=0;
+							}
 						}
 					} else {
 						root=simpScalar(c);
@@ -969,6 +996,7 @@ Object* Analitza::simp(Object* root)
 						if(root->isContainer()) {
 							c=static_cast<Container*>(root);
 							root=simpPolynomials(c);
+							
 							c=root->isContainer() ? static_cast<Container*>(root) : 0;
 						} else
 							c=0;
@@ -978,10 +1006,9 @@ Object* Analitza::simp(Object* root)
 						delete root;
 						root = new Cn(0.);
 					}
-					
 				}	break;
 				case Operator::power: {
-					for(it = c->firstValue(); it!=c->m_params.end(); it++)
+					for(it = c->firstValue(); it!=c->m_params.end(); ++it)
 						*it = simp(*it);
 					
 					if(c->m_params[2]->type()==Object::value) {
@@ -1014,7 +1041,7 @@ Object* Analitza::simp(Object* root)
 					}
 				} break;
 				case Operator::divide:
-					for(it = c->firstValue(); it!=c->m_params.end(); it++)
+					for(it = c->firstValue(); it!=c->m_params.end(); ++it)
 						*it = simp(*it);
 					
 					Object *f, *g; //f/g
@@ -1050,7 +1077,7 @@ Object* Analitza::simp(Object* root)
 					}
 					break;
 				case Operator::sum:
-					for(it = c->m_params.begin(); it!=c->m_params.end(); it++) {
+					for(it = c->m_params.begin(); it!=c->m_params.end(); ++it) {
 						if((*it)->type()==Object::container) {
 							Container *limit=static_cast<Container*>(*it);
 							if(limit->containerType()==Container::uplimit || limit->containerType()==Container::downlimit)
@@ -1108,21 +1135,20 @@ Object* Analitza::simp(Object* root)
 				default:
 					it = c->firstValue();
 					
-					for(; it!=c->m_params.end(); it++)
+					for(; it!=c->m_params.end(); ++it)
 						*it = simp(*it);
 					break;
 			}
 		} else {
 			Container::iterator it = c->firstValue();
 			
-			for(; it!=c->m_params.end(); it++)
+			for(; it!=c->m_params.end(); ++it)
 				*it = simp(*it);
 		}
 	}
 	return root;
 }
 
-
 Object* Analitza::simpScalar(Container * c)
 {
 	Object *value=0;
@@ -1197,6 +1223,7 @@ Object* Analitza::simpPolynomials(Container* c)
 	Operator o(c->firstOperator());
 	bool sign=true;
 	Container::const_iterator it(c->firstValue());
+	bool first=true;
 	
 	for(; it!=c->m_params.constEnd(); ++it) {
 		Object *o2=*it;
@@ -1254,7 +1281,11 @@ Object* Analitza::simpPolynomials(Container* c)
 			}
 		}
 		
-		bool found = false, foundAtFirst=true;
+		if(o.operatorType()==Operator::minus && !first) {
+			imono.first*=-1;
+		}
+		
+		bool found = false;
 		QList<QPair<double, Object*> >::iterator it1(monos.begin());
 		for(; it1!=monos.end(); ++it1) {
 			Object *o1=it1->second, *o2=imono.second;
@@ -1262,19 +1293,19 @@ Object* Analitza::simpPolynomials(Container* c)
 				found = true;
 				break;
 			}
-			foundAtFirst=false;
 		}
 		
 // 		qDebug() << "->" << c->toString() << c->firstOperator().toString() << found;
 		if(found) {
-			if(o.operatorType()==Operator::minus && it!=c->firstValue())
-				imono.first= -imono.first;
 			bool prevPositive=it1->first>0.;
 			it1->first += imono.first;
 			bool postPositive=it1->first>0.;
 			
-// 			qDebug() << "getting near:::" << prevPositive << postPositive << o.toString() << foundAtFirst;
-			if(foundAtFirst && o.operatorType()==Operator::minus) {
+// 			qDebug() << "getting near:::" << it1->first << prevPositive << postPositive << o.toString() << foundAtFirst;
+			if(it1->first==0.) {
+				delete it1->second;
+				monos.erase(it1);
+			} else if(o.operatorType()==Operator::minus) {
 				if(prevPositive ^ postPositive) {
 					sign = !sign;
 				}
@@ -1283,6 +1314,7 @@ Object* Analitza::simpPolynomials(Container* c)
 			imono.second = Expression::objectCopy(imono.second);
 			monos.append(imono);
 		}
+		first=false;
 	}
 	
 	delete c;
@@ -1291,6 +1323,7 @@ Object* Analitza::simpPolynomials(Container* c)
 	//We delete the empty monomials. Should merge both loops
 	QList<QPair<double, Object*> >::iterator i=monos.begin();
 	for(; i!=monos.end(); ) {
+		//FIXME: REVIEW This loop should not be needed anymore
 		if(i->first==0.) {
 			delete i->second;
 			i=monos.erase(i);
@@ -1300,19 +1333,21 @@ Object* Analitza::simpPolynomials(Container* c)
 	
 	Object *root=0;
 	if(monos.count()==1) {
-		if(o.operatorType()==Operator::minus)
-			monos[0].first *= -1.;
 		root=createMono(o, monos[0]);
 	} else if(monos.count()>1) {
 		c= new Container(Container::apply);
 		c->m_params.append(new Operator(o));
 		
 		QList<QPair<double, Object*> >::iterator i=monos.begin();
+		bool first=true;
 		for(; i!=monos.end(); ++i) {
+			if(!first && o.operatorType()==Operator::minus)
+				i->first *= -1;
 			Object* toAdd=createMono(o, *i);
 			
 			if(toAdd)
 				c->m_params.append(toAdd);
+			first=false;
 		}
 		root=c;
 	}
@@ -1456,7 +1491,7 @@ bool Analitza::hasVars(const Object *o, const QString &var, const QStringList& b
 			
 			QStringList scope=bvars;
 			
-			for(; !r && it!=c->m_params.end(); it++) {
+			for(; !r && it!=c->m_params.end(); ++it) {
 				if(it==first)
 					firstFound=true;
 				
@@ -1577,7 +1612,7 @@ void Analitza::insertVariable(const QString & name, const Object * value)
 	}
 	
 	if(!islambda && hasVars(value, name, QStringList(), m_vars)) {
-		m_err << i18n("Defined a variable cycle");
+		m_err << i18nc("By a cycle i mean a variable that depends on itself", "Defined a variable cycle");
 	} else {
 		m_vars->modify(name, value);
 	}
@@ -1624,20 +1659,20 @@ bool Analitza::hasTheVar(const QStringList & vars, const Container * c)
 double Analitza::derivative(const QList< QPair<QString, double > >& values )
 {
 	//c++ numerical recipes p. 192. Only for f'
-	QPair<QString, double> valp;
+	typedef QPair<QString, double> StringDoublePair;
 	//Image
-	foreach(valp, values) {//TODO: it should be +-hh
+	foreach(const StringDoublePair& valp, values) {//TODO: it should be +-hh
 		m_vars->stack(valp.first, valp.second);
 	}
 		
 	Object* v1=calc(m_exp.tree());
 		
-	foreach(valp, values)
+	foreach(const StringDoublePair& valp, values)
 		m_vars->destroy(valp.first);
 	
 	//Image+h
 	double h=0.00000001;
-	foreach(valp, values) {
+	foreach(const StringDoublePair& valp, values) {
 // 		volatile double temp=valp.second+h;
 // 		double hh=temp-valp.second;
 		m_vars->stack(valp.first, valp.second+h);
@@ -1645,7 +1680,7 @@ double Analitza::derivative(const QList< QPair<QString, double > >& values )
 	
 	Object* v2=calc(m_exp.tree());
 		
-	foreach(valp, values)
+	foreach(const StringDoublePair& valp, values)
 		m_vars->destroy(valp.first);
 	Q_ASSERT(v1->type()==Object::value && v2->type()==Object::value);
 	Cn *cn1=(Cn*)v1, *cn2=(Cn*)v2;
