@@ -34,7 +34,7 @@ using namespace Avogadro;
 
 // Handles localization/translation of element names
 // e.g., nitrogen in English is azote in French
-extern Avogadro::ElementTranslator Avogadro::elementTranslator;
+A_EXPORT Avogadro::ElementTranslator Avogadro::elementTranslator;
 
 MoleculeDialog::MoleculeDialog( QWidget * parent )
 	: KDialog( parent ), m_periodicTable(0), m_addHydrogens(false)
@@ -94,7 +94,7 @@ MoleculeDialog::MoleculeDialog( QWidget * parent )
   connect(ui.tabWidget, SIGNAL(currentChanged(int)),
       this, SLOT(setViewEdit(int)));
 
-  // Visualisation parameters
+  // Visualization parameters
 	connect( ui.qualityCombo, SIGNAL(activated( int )), 
 			ui.glWidget , SLOT( setQuality( int ) ) );
 	connect( ui.styleCombo, SIGNAL(activated( int )), 
@@ -223,7 +223,7 @@ void MoleculeDialog::setViewEdit(int mode)
 
 MoleculeDialog::~MoleculeDialog( )
 {
-    delete m_drawSettings;
+   delete m_drawSettings;
 }
 
 void MoleculeDialog::slotUpdateStatistics()
@@ -242,7 +242,7 @@ void MoleculeDialog::slotDownloadNewStuff()
     kDebug() << "Kalzium new stuff";
     KNS::Entry::List entries = KNS::Engine::download();
     // list of changed entries
-    foreach(KNS::Entry::Entry* entry, entries) {
+    foreach(KNS::Entry* entry, entries) {
         // care only about installed ones
         if (entry->status() == KNS::Entry::Installed) {
             kDebug() << "Files downloaded: " << entry->installedFiles();
@@ -364,7 +364,7 @@ void MoleculeDialog::slotAdjustHydrogens()
 
 void MoleculeDialog::slotGeometryOptimize()
 {
-  // Perform a geometry optimisation
+  // Perform a geometry optimization
   if (!m_forceField)
     return;
 
@@ -380,7 +380,7 @@ void MoleculeDialog::slotGeometryOptimize()
 
   // Reasonable default values for most users
   m_forceField->SteepestDescentInitialize(500, 1.0e-5);
-  // Provide some feedback as the optimisation runs
+  // Provide some feedback as the optimization runs
   while (m_forceField->SteepestDescentTakeNSteps(5))
   {
     m_forceField->UpdateCoordinates(*molecule);
