@@ -12,8 +12,8 @@
 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 
 #include "lists.h"
 
@@ -22,8 +22,6 @@
 #include "object_hierarchy.h"
 #include "../kig/kig_part.h"
 
-#include "config.h"
-
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <qfile.h>
@@ -251,7 +249,7 @@ bool MacroList::save( const std::vector<Macro*>& ms, const QString& f )
 
   QDomElement docelem = doc.createElement( "KigMacroFile" );
   docelem.setAttribute( "Version", KIGVERSION );
-  docelem.setAttribute( "Number", ms.size() );
+  docelem.setAttribute( "Number", static_cast<uint>( ms.size() ) );
 
   for ( uint i = 0; i < ms.size(); ++i )
   {
@@ -270,7 +268,7 @@ bool MacroList::save( const std::vector<Macro*>& ms, const QString& f )
     macroelem.appendChild( descelem );
 
     // icon
-    QCString icon = ctor->iconFileName( true );
+    QByteArray icon = ctor->iconFileName( true );
     if ( !icon.isNull() )
     {
       QDomElement descelem = doc.createElement( "IconFileName" );
@@ -289,25 +287,25 @@ bool MacroList::save( const std::vector<Macro*>& ms, const QString& f )
   doc.appendChild( docelem );
 
   QFile file( f );
-  if ( ! file.open( IO_WriteOnly ) )
+  if ( ! file.open( QIODevice::WriteOnly ) )
     return false;
   QTextStream stream( &file );
-  stream << doc.toCString();
+  stream << doc.toByteArray();
   return true;
 }
 
 bool MacroList::load( const QString& f, std::vector<Macro*>& ret, const KigPart& kdoc )
 {
   QFile file( f );
-  if ( ! file.open( IO_ReadOnly ) )
+  if ( ! file.open( QIODevice::ReadOnly ) )
   {
-    KMessageBox::sorry( 0, i18n( "Could not open macro file '%1'" ).arg( f ) );
+    KMessageBox::sorry( 0, i18n( "Could not open macro file '%1'", f ) );
     return false;
   }
   QDomDocument doc( "KigMacroFile" );
   if ( !doc.setContent( &file ) )
   {
-    KMessageBox::sorry( 0, i18n( "Could not open macro file '%1'" ).arg( f ) );
+    KMessageBox::sorry( 0, i18n( "Could not open macro file '%1'", f ) );
     return false;
   }
   file.close();
@@ -318,7 +316,7 @@ bool MacroList::load( const QString& f, std::vector<Macro*>& ret, const KigPart&
   else
   {
     KMessageBox::detailedSorry(
-      0, i18n( "Kig cannot open the macro file \"%1\"." ).arg( f ),
+      0, i18n( "Kig cannot open the macro file \"%1\".", f ),
       i18n( "This file was created by a very old Kig version (pre-0.4). "
             "Support for this format has been removed from recent Kig versions. "
             "You can try to import this macro using a previous Kig version "
@@ -352,7 +350,8 @@ bool MacroList::loadNew( const QDomElement& docelem, std::vector<Macro*>& ret, c
   {
     QString name, description;
     ObjectHierarchy* hierarchy = 0;
-    QCString actionname, iconfile;
+    QByteArray actionname;
+    QByteArray iconfile( "system-run" );
     if ( macroelem.tagName() != "Macro" ) continue; // forward compat ?
     for ( QDomElement dataelem = macroelem.firstChild().toElement();
           ! dataelem.isNull(); dataelem = dataelem.nextSibling().toElement() )
@@ -364,17 +363,23 @@ bool MacroList::loadNew( const QDomElement& docelem, std::vector<Macro*>& ret, c
       else if ( dataelem.tagName() == "Construction" )
         hierarchy = ObjectHierarchy::buildSafeObjectHierarchy( dataelem, tmp );
       else if ( dataelem.tagName() == "ActionName" )
-        actionname = dataelem.text().latin1();
+        actionname = dataelem.text().toLatin1();
       else if ( dataelem.tagName() == "IconFileName" )
-        iconfile = dataelem.text().latin1();
+        iconfile = dataelem.text().toLatin1();
       else continue;
     };
     assert( hierarchy );
     // if the macro has no name, we give it a bogus name...
+    bool name_i18ned = false;
     if ( name.isEmpty() )
-      name = i18n( "Unnamed Macro #%1" ).arg( unnamedindex++ );
+    {
+      name = i18n( "Unnamed Macro #%1", unnamedindex++ );
+      name_i18ned = true;
+    }
     MacroConstructor* ctor =
-      new MacroConstructor( *hierarchy, i18n( name.latin1() ), i18n( description.latin1() ), iconfile );
+      new MacroConstructor( *hierarchy, name_i18ned ? name : i18n( name.toUtf8() ),
+                            description.isEmpty() ? QString() : i18n( description.toUtf8() ),
+                            iconfile );
     delete hierarchy;
     GUIAction* act = new ConstructibleAction( ctor, actionname );
     Macro* macro = new Macro( act, ctor );
