@@ -30,6 +30,7 @@
 #include "constellationboundary.h"
 #include "constellationboundarylines.h"
 #include "constellationlines.h"
+#include "culturelist.h"
 #include "constellationnamescomponent.h"
 #include "coordinategrid.h"
 #include "customcatalogcomponent.h"
@@ -39,8 +40,10 @@
 #include "horizoncomponent.h"
 #include "jupitermoonscomponent.h"
 #include "milkyway.h"
+#include "magellanicclouds.h"
 #include "solarsystemcomposite.h"
 #include "starcomponent.h"
+#include "deepstarcomponent.h"
 #include "satellitecomposite.h"
 
 #include "skymesh.h"
@@ -62,6 +65,8 @@ SkyMapComposite::SkyMapComposite(SkyComponent *parent, KStarsData *data) :
     //Add all components
     m_MilkyWay = new MilkyWay( this );
     addComponent( m_MilkyWay );
+    m_MagellanicClouds = new MagellanicClouds( this );
+    addComponent( m_MagellanicClouds );
     //Stars must come before constellation lines
     m_Stars = new StarComponent( this );
     addComponent( m_Stars );
@@ -72,6 +77,8 @@ SkyMapComposite::SkyMapComposite(SkyComponent *parent, KStarsData *data) :
     m_CBoundLines = new ConstellationBoundaryLines( this );
     addComponent( m_CBoundLines );
 
+    m_Cultures = new CultureList();
+
     m_CLines = new ConstellationLines( this );
     addComponent( m_CLines );
 
@@ -115,6 +122,7 @@ SkyMapComposite::~SkyMapComposite()
 {
     delete m_skyLabeler;     // These are on the heap to avoid header file hell.
     delete m_skyMesh;
+    delete m_Cultures;
 }
 
 void SkyMapComposite::update(KStarsData *data, KSNumbers *num )
@@ -212,9 +220,13 @@ void SkyMapComposite::draw( QPainter& psky )
 
     m_MilkyWay->draw( psky );
 
+    m_MagellanicClouds->draw( psky );
+
     m_CoordinateGrid->draw( psky );
 
-    m_CBoundLines->draw( psky );
+    // Draw constellation boundary lines only if we draw western constellations
+    if ( m_Cultures->current() == "Western" )
+        m_CBoundLines->draw( psky );
 
     m_CLines->draw( psky );
 
@@ -279,6 +291,8 @@ SkyObject* SkyMapComposite::objectNearest( SkyPoint *p, double &maxrad ) {
     //reduce rBest by 0.75 for stars brighter than 4th mag
     if ( oBest && oBest->mag() < 4.0 ) rBest *= 0.75;
 
+    // TODO: Add support for deep star catalogs
+
     //m_DeepSky internally discriminates among deepsky catalogs
     //and renormalizes rTry
     oTry = m_DeepSky->objectNearest( p, rTry );
@@ -287,6 +301,15 @@ SkyObject* SkyMapComposite::objectNearest( SkyPoint *p, double &maxrad ) {
         oBest = oTry;
     }
 
+    for( int i = 0; i < m_DeepStars.size(); ++i ) {
+      rTry = maxrad;
+      oTry = m_DeepStars.at( i )->objectNearest( p, rTry );
+      if( rTry < rBest ) {
+	rBest = rTry;
+	oBest = oTry;
+      }
+    }
+
     rTry = maxrad;
     oTry = m_CustomCatalogs->objectNearest( p, rTry );
     rTry *= 0.5;
@@ -318,6 +341,8 @@ SkyObject* SkyMapComposite::starNearest( SkyPoint *p, double &maxrad ) {
     //reduce rBest by 0.75 for stars brighter than 4th mag
     if ( star && star->mag() < 4.0 ) rtry *= 0.75;
 
+    // TODO: Add Deep Star Catalog support
+
     maxrad = rtry;
     return star;
 }
@@ -414,6 +439,21 @@ SkyObject* SkyMapComposite::findStarByGenetiveName( const QString &name ) {
 }
 **/
 
+KSPlanetBase* SkyMapComposite::planet( int n ) {
+    if ( n == KSPlanetBase::SUN ) return (KSPlanetBase*)(m_SolarSystem->findByName( "Sun" ) );
+    if ( n == KSPlanetBase::MERCURY ) return (KSPlanetBase*)(m_SolarSystem->findByName( i18n( "Mercury" ) ) );
+    if ( n == KSPlanetBase::VENUS ) return (KSPlanetBase*)(m_SolarSystem->findByName( i18n( "Venus" ) ) );
+    if ( n == KSPlanetBase::MOON ) return (KSPlanetBase*)(m_SolarSystem->findByName( "Moon" ) );
+    if ( n == KSPlanetBase::MARS ) return (KSPlanetBase*)(m_SolarSystem->findByName( i18n( "Mars" ) ) );
+    if ( n == KSPlanetBase::JUPITER ) return (KSPlanetBase*)(m_SolarSystem->findByName( i18n( "Jupiter" ) ) );
+    if ( n == KSPlanetBase::SATURN ) return (KSPlanetBase*)(m_SolarSystem->findByName( i18n( "Saturn" ) ) );
+    if ( n == KSPlanetBase::URANUS ) return (KSPlanetBase*)(m_SolarSystem->findByName( i18n( "Uranus" ) ) );
+    if ( n == KSPlanetBase::NEPTUNE ) return (KSPlanetBase*)(m_SolarSystem->findByName( i18n( "Neptune" ) ) );
+    if ( n == KSPlanetBase::PLUTO ) return (KSPlanetBase*)(m_SolarSystem->findByName( i18n( "Pluto" ) ) );
+
+	return 0;
+}
+
 void SkyMapComposite::addCustomCatalog( const QString &filename, KStarsData *data, int index ) {
     CustomCatalogComponent *cc = new CustomCatalogComponent( this, filename, false, index );
     cc->init( data );
@@ -451,6 +491,25 @@ void SkyMapComposite::reloadComets( KStarsData *data ) {
     m_SolarSystem->reloadComets( data );
 }
 
+void SkyMapComposite::reloadCLines( KStarsData *data ) {
+    if( m_CLines ) 
+        delete m_CLines;
+    m_CLines = new ConstellationLines( this );
+    m_CLines->init( data );
+}
+
+void SkyMapComposite::reloadCNames( KStarsData *data ) {
+    objectNames(SkyObject::CONSTELLATION).clear();
+    if( m_CNames )
+        delete m_CNames;
+    m_CNames = new ConstellationNamesComponent( this );
+    m_CNames->init( data );
+}
+
+bool SkyMapComposite::isLocalCNames() {
+    return m_CNames->isLocalCNames();
+}
+
 void SkyMapComposite::emitProgressText( const QString &message ) {
     emit progressText( message );
     qApp->processEvents();         // -jbb: this seemed to make it work.
@@ -481,10 +540,12 @@ QList<SkyObject*>& SkyMapComposite::constellationNames() {
     return m_CNames->objectList();
 }
 
+// Returns only named stars, and should not be used
 QList<SkyObject*>& SkyMapComposite::stars() {
     return m_Stars->objectList();
 }
 
+
 QList<SkyObject*>& SkyMapComposite::asteroids() {
     return m_SolarSystem->asteroids();
 }
@@ -501,4 +562,20 @@ QList<SkyComponent*> SkyMapComposite::customCatalogs() {
     return m_CustomCatalogs->components();
 }
 
+QStringList SkyMapComposite::getCultureNames() {
+    return m_Cultures->getNames();
+}
+
+QString SkyMapComposite::getCultureName( int index ) {
+    return m_Cultures->getName( index );
+}
+
+void SkyMapComposite::setCurrentCulture( QString culture ) {
+    m_Cultures->setCurrent( culture );
+}
+
+QString SkyMapComposite::currentCulture() {
+    return m_Cultures->current();
+}
+
 #include "skymapcomposite.moc"
