@@ -581,7 +581,7 @@ void Executer::executeForTo(TreeNode* node) {
 
 	if (
  	(startCondition < endCondition && currentCount + step <= endCondition) ||
-	    (startCondition > endCondition && currentCount - step >= endCondition && step<0) //negative loop sanity check, is it implemented?
+	    (startCondition > endCondition && currentCount + step >= endCondition && step<0) //negative loop sanity check, is it implemented?
 		|| (startCondition==endCondition && firstIteration) // for expressions like for $n=1 to 1
 	   ) {
 	if (!firstIteration)
