@@ -16,6 +16,11 @@
 #include <QtCore/QPair>
 #include <QtCore/QString>
 
+class QByteArray;
+
+namespace Marble
+{
+
 class DiscCache
 {
     public:
@@ -42,4 +47,6 @@ class DiscCache
         QMap<QString, Entry> m_Entries;
 };
 
+}
+
 #endif
