@@ -15,8 +15,7 @@
 
 #include <QtCore/QCoreApplication>
 #include <QtCore/QDebug>
-#include <QtCore/QLocale>
-#include <QtCore/QTranslator>
+#include <QtCore/QTimer>
 #include <QtCore/QAbstractItemModel>
 #include <QtGui/QItemSelectionModel>
 #include <QtGui/QSizePolicy>
@@ -74,6 +73,7 @@ class MarbleWidgetPrivate
           m_stillQuality( Marble::High ), m_animationQuality( Marble::Low ),
           m_animationsEnabled( false ),
           m_inputhandler( 0 ),
+          m_popupmenu( 0 ),
           m_physics( new MarblePhysics() ),
           m_proxyHost(),
           m_proxyPort( 0 )
@@ -112,6 +112,8 @@ class MarbleWidgetPrivate
 
     QString          m_proxyHost;
     qint16           m_proxyPort;
+
+    void _q_initGui();
 };
 
 
@@ -123,6 +125,9 @@ MarbleWidget::MarbleWidget(QWidget *parent)
 //    QDBusConnection::sessionBus().registerObject("/marble", this, QDBusConnection::QDBusConnection::ExportAllSlots);
 
     d->construct();
+
+    // Delayed model initialization
+    QTimer::singleShot( 0, this, SLOT( _q_initGui() ) );
 }
 
 
@@ -133,6 +138,9 @@ MarbleWidget::MarbleWidget(MarbleMap *map, QWidget *parent)
 //    QDBusConnection::sessionBus().registerObject("/marble", this, QDBusConnection::QDBusConnection::ExportAllSlots);
 
     d->construct();
+
+    // Delayed model initialization
+    QTimer::singleShot( 0, this, SLOT( _q_initGui() ) );
 }
 
 MarbleWidget::~MarbleWidget()
@@ -183,21 +191,6 @@ void MarbleWidgetPrivate::construct()
     // displayed on the widget background.
     m_widget->setAutoFillBackground( true );
 
-    m_inputhandler = 0;
-    m_popupmenu    = new MarbleWidgetPopupMenu( m_widget, m_model );
-
-    // Handle mouse and keyboard input.
-    m_widget->setInputHandler( new MarbleWidgetDefaultInputHandler );
-    m_widget->setMouseTracking( true );
-
-    // The interface to the measure tool consists of a RMB popup menu
-    // and some signals.
-    MeasureTool  *measureTool = m_map->measureTool();
-    m_widget->connect( m_popupmenu, SIGNAL( addMeasurePoint( qreal, qreal ) ),
-                       measureTool, SLOT( addMeasurePoint( qreal, qreal ) ) );
-    m_widget->connect( m_popupmenu, SIGNAL( removeMeasurePoints() ),
-                       measureTool, SLOT( removeMeasurePoints( ) ) );
-
     // Track the GPS current point at timely intervals.
     m_widget->connect( m_model, SIGNAL( timeout() ),
                        m_widget, SLOT( updateGps() ) );
@@ -218,6 +211,35 @@ void MarbleWidgetPrivate::construct()
 
     m_widget->connect( m_physics, SIGNAL( valueChanged( qreal ) ),
                         m_widget, SLOT( updateAnimation( qreal ) ) );
+
+    m_widget->connect( m_model->sunLocator(), SIGNAL( centerSun() ),
+                        m_widget, SLOT( centerSun() ) );
+}
+
+void MarbleWidgetPrivate::_q_initGui() {
+    // Handle mouse and keyboard input.
+    m_widget->setInputHandler( new MarbleWidgetDefaultInputHandler );
+    m_widget->setMouseTracking( true );
+
+    // The interface to the measure tool consists of a RMB popup menu
+    // and some signals.
+    MeasureTool  *measureTool = m_map->measureTool();
+
+    // Connect the inputHandler and the measure tool to the popup menu
+    // FIXME: This needs REFACTORING, as a custom input handler is will likely want to have 
+    // a different popup menu.
+    if ( !m_popupmenu ) {
+        m_popupmenu    = new MarbleWidgetPopupMenu( m_widget, m_model );
+    }
+    m_widget->connect( m_inputhandler, SIGNAL( lmbRequest( int, int ) ),
+                       m_popupmenu,    SLOT( showLmbMenu( int, int ) ) );
+    m_widget->connect( m_inputhandler, SIGNAL( rmbRequest( int, int ) ),
+                       m_popupmenu,    SLOT( showRmbMenu( int, int ) ) );
+
+    m_widget->connect( m_popupmenu, SIGNAL( addMeasurePoint( qreal, qreal ) ),
+                       measureTool, SLOT( addMeasurePoint( qreal, qreal ) ) );
+    m_widget->connect( m_popupmenu, SIGNAL( removeMeasurePoints() ),
+                       measureTool, SLOT( removeMeasurePoints( ) ) );
 }
 
 // ----------------------------------------------------------------
@@ -244,10 +266,7 @@ void MarbleWidget::setInputHandler(MarbleWidgetInputHandler *handler)
     if ( d->m_inputhandler ) {
         d->m_inputhandler->init( this );
         installEventFilter( d->m_inputhandler );
-        connect( d->m_inputhandler, SIGNAL( lmbRequest( int, int ) ),
-                 d->m_popupmenu,    SLOT( showLmbMenu( int, int ) ) );
-        connect( d->m_inputhandler, SIGNAL( rmbRequest( int, int ) ),
-                 d->m_popupmenu,    SLOT( showRmbMenu( int, int ) ) );
+
         connect( d->m_inputhandler, SIGNAL( mouseClickScreenPosition( int, int) ),
                  this,              SLOT( notifyMouseClick( int, int ) ) );
 
@@ -714,11 +733,13 @@ void MarbleWidget::leaveEvent (QEvent*)
 
 void MarbleWidget::resizeEvent (QResizeEvent*)
 {
+    setUpdatesEnabled( false );
     d->m_map->setSize( width(), height() );
 
     setAttribute(Qt::WA_NoSystemBackground, d->m_map->mapCoversViewport() && !mapThemeId().isEmpty() );
 
     repaint();
+    setUpdatesEnabled( true );
 }
 
 void MarbleWidget::connectNotify ( const char * signal )
@@ -1261,7 +1282,6 @@ void MarbleWidget::centerSun()
     qreal  lat = sunLocator->getLat();
     centerOn( lon, lat );
 
-    qDebug() << "centering on Sun at" << lat << lon;
     disableInput();
 }
 
@@ -1272,14 +1292,18 @@ SunLocator* MarbleWidget::sunLocator()
 
 void MarbleWidget::enableInput()
 {
-    if ( !d->m_inputhandler ) 
+    if ( !d->m_inputhandler ) {
         setInputHandler( new MarbleWidgetDefaultInputHandler );
+    }
+    else {
+        installEventFilter( d->m_inputhandler );
+    }
 }
 
 void MarbleWidget::disableInput()
 {
     qDebug() << "MarbleWidget::disableInput";
-    setInputHandler( 0 );
+    removeEventFilter( d->m_inputhandler );
     setCursor( Qt::ArrowCursor );
 }
 
