@@ -5,7 +5,7 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2008      Inge Wallin  <ingwa@kde.org>"
+// Copyright 2008      Inge Wallin  <ingwa@kde.org>
 //
 
 
@@ -22,8 +22,11 @@
 
 #include "AbstractProjectionHelper.h"
 
+namespace Marble
+{
+
 /**
- * @short A base class for all projections in Marble.
+ * @short The projection helper for the Spherical projection
  */
 
 class SphericalProjectionHelper : public AbstractProjectionHelper
@@ -39,10 +42,10 @@ class SphericalProjectionHelper : public AbstractProjectionHelper
     virtual ~SphericalProjectionHelper();
 
     void paintBase( GeoPainter     *painter, 
-		    ViewportParams *viewport,
-		    QPen           &pen,
-		    QBrush         &brush,
-		    bool            antialiasing );
+                    ViewportParams *viewport,
+                    QPen           &pen,
+                    QBrush         &brush,
+                    bool            antialiasing );
 
     void createActiveRegion( ViewportParams *viewport );
     void createProjectedRegion( ViewportParams *viewport );
@@ -51,5 +54,6 @@ class SphericalProjectionHelper : public AbstractProjectionHelper
     //SphericalProjectionPrivate  * const d;
 };
 
+}
 
 #endif // SPHERICALPROJECTIONHELPER_H
