@@ -19,9 +19,15 @@
 #ifndef TINYWEBBROWSER_H
 #define TINYWEBBROWSER_H
 
-#include <QDebug>
+#include <QtCore/QString>
+#include <QtCore/QVariant>
 #include <QtGui/QTextBrowser>
-#include <QImage>
+
+class QUrl;
+
+namespace Marble
+{
+
 class HttpDownloadManager;
 class CacheStoragePolicy;
 
@@ -58,5 +64,6 @@ class TinyWebBrowser : public QTextBrowser
         QString         m_source;
 };
 
+}
 
 #endif // TINYWEBBROWSER_H
