@@ -23,12 +23,18 @@
 
 #include "GeoTagHandler.h"
 
-class KmlroleTagHandler : public GeoTagHandler {
-public:
-    KmlroleTagHandler();
-    virtual ~KmlroleTagHandler();
+namespace Marble
+{
+namespace kml
+{
 
+class KmlroleTagHandler : public GeoTagHandler
+{
+public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // KmlroleTagHandler_h
